@@ -1,4 +1,4 @@
-# $Id: Content.pm,v 1.13 2002/10/15 21:07:37 joern Exp $
+# $Id: Content.pm,v 1.14 2002/11/03 11:36:58 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -62,23 +62,18 @@ sub read_title_listing {
 
 	my $title_cnt;
 
-	if ( $rip_mode ne 'vob_title' ) {
-		# execute tcprobe to get the number of titles
-		my $output = $self->system (
-			command => "tcprobe -i $data_source"
-		);
+	# execute tcprobe to get the number of titles
+	my $output = $self->system (
+		command => "tcprobe -i $data_source"
+	);
 	
-		($title_cnt) = $output =~ m!DVD\s+title\s+\d+/(\d+)!;
+	($title_cnt) = $output =~ m!DVD\s+title\s+\d+/(\d+)!;
 
-		# Fatal error if we can't determine the title cnt
-		if ( not $title_cnt ) {
-			croak "Can't determine number of titles.\n".
-			      "Please put the DVD in your drive.\n".
-			      "tcprobe output was:\n$output";
-		}
-	
-	} else {
-		$title_cnt = 1;
+	# Fatal error if we can't determine the title cnt
+	if ( not $title_cnt ) {
+		croak "Can't determine number of titles.\n".
+		      "Please put the DVD in your drive.\n".
+		      "tcprobe output was:\n$output";
 	}
 	
 	my ($nr, %titles);
