@@ -1,4 +1,4 @@
-# $Id: Main.pm,v 1.53 2002/11/01 13:30:59 joern Exp $
+# $Id: Main.pm,v 1.54 2002/11/12 22:05:21 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -43,6 +43,15 @@ sub start {
 	@par{'filename','open_cluster_control','function','select_title'};
 
 	Gtk->init;
+
+#Gtk::Rc->parse_string(<<"EOF");
+#style "user-font"
+#{
+#  fontset="-adobe-helvetica-medium-r-normal-*-*-100-*-*-*-*-*-*"
+#}
+#widget_class "*" style "user-font"
+#EOF
+
 	Gtk::Widget->set_default_colormap(Gtk::Gdk::Rgb->get_cmap());
 	Gtk::Widget->set_default_visual(Gtk::Gdk::Rgb->get_visual());
 
@@ -324,7 +333,6 @@ sub create_menubar {
 		  	$self->comp('project')->add_to_cluster
 		} },
                 { path        => '/_Operate/Create splitted _vobsub(s)',
-# 		  accelerator => '<control>v',
                   callback    => sub {
 		  	return 1 if not $self->project_opened;
 		  	$self->comp('project')->create_splitted_vobsub
@@ -334,6 +342,17 @@ sub create_menubar {
 		  	return 1 if not $self->project_opened;
 		  	$self->comp('project')->create_non_splitted_vobsub
 		} },
+                { path        => '/_Operate/Create dvdrip-info file',
+                  callback    => sub {
+		  	return 1 if not $self->project_opened;
+			my $title = $self->comp('project')->selected_title;
+			return 1 if not $title;
+			Video::DVDRip::InfoFile->new (
+				title    => $title,
+				filename => $title->info_file,
+			)->write;
+			1;
+		} },
 
 
 		{ path        => '/_Cluster',
