@@ -1,4 +1,4 @@
-# $Id: SubtitleTab.pm,v 1.5 2002/11/01 16:11:34 joern Exp $
+# $Id: SubtitleTab.pm,v 1.8 2002/11/17 17:16:51 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -134,7 +134,12 @@ sub create_subtitle_select {
 	$table->attach ($hbox, 1, 2, $row, $row+1, 'fill','expand',0,0);
 
 	my $selected = $TC::VERSION >= 601.2002101 ?
-		"Activated:" : "You need transcode v0.6.1.20021010 or better.";
+		"Activated:" : "You need transcode v0.6.2.20021010 or better.";
+
+	if ( $TC::VERSION < 601.2002101 ) {
+		$widgets->{selection_popup}->hide;
+		
+	}
 
 	$label = Gtk::Label->new ("$selected");
 	$label->show;
@@ -228,9 +233,9 @@ sub create_subtitle_preview {
 	$hbox->pack_start ($label, 0, 1, 0);
 
 	$entry = Video::DVDRip::CheckedEntry->new (undef,
-		is_number      => 1,
-		may_fractional => 0,
-		may_empty      => 0,
+		is_frame_or_timecode => 1,
+		may_fractional       => 0,
+		may_empty            => 0,
 	);
 	$entry->show;
 	$entry->set_usize (80, undef);
@@ -349,6 +354,9 @@ sub create_subtitle_render {
 	$entry->set_usize($ENTRY_SIZE,undef);
 	$entry->show;
 	$hbox->pack_start ($entry, 0, 1, 0);
+	$label = Gtk::Label->new ("rows");
+	$label->show;
+	$hbox->pack_start ($label, 0, 1, 0);
 	$table->attach ($hbox, 1, 2, $row, $row+1, 'fill','expand',0,0);
 
 	$widgets->{tc_vertical_offset_label} = $label;
@@ -375,6 +383,9 @@ sub create_subtitle_render {
 	$entry->set_usize($ENTRY_SIZE,undef);
 	$entry->show;
 	$hbox->pack_start ($entry, 0, 1, 0);
+	$label = Gtk::Label->new ("ms");
+	$label->show;
+	$hbox->pack_start ($label, 0, 1, 0);
 	$table->attach ($hbox, 1, 2, $row, $row+1, 'fill','expand',0,0);
 
 	$widgets->{tc_time_shift_label} = $label;
@@ -867,7 +878,6 @@ sub init_subtitle_values {
 				"No subtitles available" :
 				"Title isn't ripped"
 		);
-		$title->set_selected_subtitle_id ( -1 );
 	}
 
 	my $item;
@@ -877,7 +887,7 @@ sub init_subtitle_values {
 	
 	my $history = 0;
 	my $i = 0;
-	foreach my $key ( sort keys %popup_entries ) {
+	foreach my $key ( sort { $a <=> $b } keys %popup_entries ) {
 		$item = Gtk::MenuItem->new ($popup_entries{$key});
 		$item->show;
 		$popup_menu->append($item);
@@ -1188,6 +1198,17 @@ sub subtitle_test_transcode {
 	
 	my $title = $self->selected_title;
 	return 1 if not $title;
+
+	my $subtitle = $title->selected_subtitle;
+	return 1 if not $subtitle;
+
+	if ( not $subtitle->preview_images or
+	     @{$subtitle->preview_images} == 0 ) {
+		$self->message_window (
+			message => "Please grab preview images first."
+		);
+		return 1;
+	}
 	
 	$self->transcode ( subtitle_test => 1 );
 	
@@ -1208,6 +1229,15 @@ sub subtitle_test_view {
 	
 	$filename .= "*.mpg" if $filename !~ /\.[^.]+$/;
 	
+	my @files = glob ($filename);
+
+	if ( @files == 0 or not -f $files[0] ) {
+		$self->message_window (
+			message => "You need to transcode the subtitles first."
+		);
+		return 1;
+	}
+	
 	my $command = $title->get_view_avi_command (
 		command_tmpl => $self->config('play_file_command'),
 		file => $filename,
