@@ -1,4 +1,4 @@
-# $Id: TitleTab.pm,v 1.47 2002/11/01 13:31:30 joern Exp $
+# $Id: TitleTab.pm,v 1.48 2002/11/03 11:35:16 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -637,9 +637,6 @@ sub read_dvd_toc {
 
 	$self->clear_content_list;
 
-	my $mounted = $project->dvd_is_mounted;
-	$project->mount_dvd if not $mounted;
-
 	# read TOC
 	eval {
 		$project->check_dvd_in_drive;
@@ -653,7 +650,6 @@ sub read_dvd_toc {
 				   "Internal message was:\n".
 				   $self->stripped_exception
 		);
-		$project->umount_dvd if not $mounted;
 		return;
 	}
 	
@@ -682,8 +678,6 @@ sub read_dvd_toc {
 	}
 	
 	$exec->set_cb_finished (sub{
-		$project->umount_dvd if not $mounted;
-
 		return if $exec->cancelled;
 
 		my $nr = $self->clist_row2title_nr->{0};
@@ -693,7 +687,16 @@ sub read_dvd_toc {
 		$self->set_selected_title( $title );
 		$self->fill_with_values;
 		$self->rip_title_widgets->{content_clist}->select_row (0,0);
-		$self->project->copy_ifo_files;
+		eval { $self->project->copy_ifo_files };
+		if ( $@ ) {
+			$self->long_message_window (
+				message =>
+					"Failed to copy the IFO files. vobsub creation ".
+					"won't work properly.\nThe error message is:\n".
+					$self->stripped_exception
+					
+			);
+		}
 		$self->project->backup_copy;
 
 		1;
@@ -842,16 +845,12 @@ sub rip_title {
 
 	my $project = $self->comp('project')->project;
 
-	my $mounted = $project->dvd_is_mounted;
-	$project->mount_dvd if not $mounted;
-
 	eval { $self->project->check_dvd_in_drive };
 	if ( $@ ) {
 		$self->rip_title_selection_sensitive(1);
 		$self->message_window (
 			message => "Please put a disc into your drive. ($@)"
 		);
-		$project->umount_dvd if not $mounted;
 		return;
 	}
 
@@ -885,8 +884,6 @@ sub rip_title {
 	}
 
 	$exec->set_cb_finished (sub {
-		$project->umount_dvd if not $mounted;
-
 		if ( $exec->cancelled ) {
 			$exec->cancelled_job->title->remove_vob_files
 				if $exec->cancelled_job;
