@@ -1,4 +1,4 @@
-# $Id: TranscodeTab.pm,v 1.60 2002/11/01 16:11:35 joern Exp $
+# $Id: TranscodeTab.pm,v 1.61 2002/11/12 22:07:20 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -96,7 +96,7 @@ sub create_transcode_tab {
 			       tc_video_framerate tc_execute_afterwards
 			       tc_start_frame tc_end_frame
 			       tc_target_size )) {
-		my $signal = ($attr eq 'tc_target_size' or $attr eq 'tc_video_bitrate')
+		my $signal = ($attr =~ /^tc_(target_size|video_bitrate|video_codec)$/ )
 			? "changed" : "focus-out-event";
 		$widgets->{$attr}->signal_connect ($signal, sub {
 			my ($widget, $method) = @_;
@@ -122,6 +122,8 @@ sub create_transcode_tab {
 					$self->burn_widgets
 					     ->{burn_cd_type_iso}->set_active(1);
 				}
+				$self->selected_title->calc_video_bitrate;
+				$self->init_transcode_values;
 			}
 			1;
 		}, "set_$attr");
@@ -194,79 +196,8 @@ sub create_video_options {
 	$table->set_col_spacings ( $TABLE_SPACING );
 	$frame_hbox->pack_start ($table, 1, 1, 0);
 
-	# Deinterlace
-	$row = 0;
-	$hbox = Gtk::HBox->new;
-	$hbox->show;
-	$label = Gtk::Label->new ("Deinterlace mode");
-	$label->show;
-	$hbox->pack_start($label, 0, 1, 0);
-	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
-	$hsize_group->add ($hbox);
-
-	$popup_menu = Gtk::Menu->new;
-	$popup_menu->show;
-	$popup = Gtk::OptionMenu->new;
-	$popup->show;
-	$popup->set_usize(180,undef);
-	$popup->set_menu($popup_menu);
-
-	foreach my $key ( sort keys %Video::DVDRip::deinterlace_filters ) {
-		$item = Gtk::MenuItem->new (
-			$Video::DVDRip::deinterlace_filters{$key}
-		);
-		$item->show;
-		$popup_menu->append($item);
-		$item->signal_connect (
-			"activate", sub {
-				return 1 if not $self->selected_title;
-				return 1 if $self->in_transcode_init;
-				$self->selected_title
-				     ->set_tc_deinterlace($key)
-			}, $key
-		);
-	}
-	$table->attach ($popup, 1, 2, $row, $row+1, 'fill','expand',0,0);
-
-	$self->transcode_widgets->{tc_deinterlace_popup} = $popup;
-
-	# Antialias
-	++$row;
-	$hbox = Gtk::HBox->new;
-	$hbox->show;
-	$label = Gtk::Label->new ("Antialias mode");
-	$label->show;
-	$hbox->pack_start($label, 0, 1, 0);
-	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
-	$hsize_group->add ($hbox);
-
-	$popup_menu = Gtk::Menu->new;
-	$popup_menu->show;
-	$popup = Gtk::OptionMenu->new;
-	$popup->show;
-	$popup->set_menu($popup_menu);
-
-	foreach my $key ( sort keys %Video::DVDRip::antialias_filters ) {
-		$item = Gtk::MenuItem->new (
-			$Video::DVDRip::antialias_filters{$key}
-		);
-		$item->show;
-		$popup_menu->append($item);
-		$item->signal_connect (
-			"activate", sub {
-				return 1 if not $self->selected_title;
-				return 1 if $self->in_transcode_init;
-				$self->selected_title
-				     ->set_tc_anti_alias($key)
-			}, $key
-		);
-	}
-	$table->attach_defaults ($popup, 1, 2, $row, $row+1);
-
-	$self->transcode_widgets->{tc_anti_alias_popup} = $popup;
-
 	# Video Codec
-	++$row;
+	$row = 0;
 	$hbox = Gtk::HBox->new;
 	$hbox->show;
 	$label = Gtk::Label->new ("Video codec");
@@ -386,6 +317,77 @@ sub create_video_options {
 	$self->transcode_widgets->{tc_multipass_yes} = $radio_yes;
 	$self->transcode_widgets->{tc_multipass_no}  = $radio_no;
 
+	# Deinterlace
+	++$row;
+	$hbox = Gtk::HBox->new;
+	$hbox->show;
+	$label = Gtk::Label->new ("Deinterlace mode");
+	$label->show;
+	$hbox->pack_start($label, 0, 1, 0);
+	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
+	$hsize_group->add ($hbox);
+
+	$popup_menu = Gtk::Menu->new;
+	$popup_menu->show;
+	$popup = Gtk::OptionMenu->new;
+	$popup->show;
+	$popup->set_usize(180,undef);
+	$popup->set_menu($popup_menu);
+
+	foreach my $key ( sort keys %Video::DVDRip::deinterlace_filters ) {
+		$item = Gtk::MenuItem->new (
+			$Video::DVDRip::deinterlace_filters{$key}
+		);
+		$item->show;
+		$popup_menu->append($item);
+		$item->signal_connect (
+			"activate", sub {
+				return 1 if not $self->selected_title;
+				return 1 if $self->in_transcode_init;
+				$self->selected_title
+				     ->set_tc_deinterlace($key)
+			}, $key
+		);
+	}
+	$table->attach ($popup, 1, 2, $row, $row+1, 'fill','expand',0,0);
+
+	$self->transcode_widgets->{tc_deinterlace_popup} = $popup;
+
+	# Antialias
+	++$row;
+	$hbox = Gtk::HBox->new;
+	$hbox->show;
+	$label = Gtk::Label->new ("Antialias mode");
+	$label->show;
+	$hbox->pack_start($label, 0, 1, 0);
+	$table->attach ($hbox, 0, 1, $row, $row+1, 'fill','expand',0,0);
+	$hsize_group->add ($hbox);
+
+	$popup_menu = Gtk::Menu->new;
+	$popup_menu->show;
+	$popup = Gtk::OptionMenu->new;
+	$popup->show;
+	$popup->set_menu($popup_menu);
+
+	foreach my $key ( sort keys %Video::DVDRip::antialias_filters ) {
+		$item = Gtk::MenuItem->new (
+			$Video::DVDRip::antialias_filters{$key}
+		);
+		$item->show;
+		$popup_menu->append($item);
+		$item->signal_connect (
+			"activate", sub {
+				return 1 if not $self->selected_title;
+				return 1 if $self->in_transcode_init;
+				$self->selected_title
+				     ->set_tc_anti_alias($key)
+			}, $key
+		);
+	}
+	$table->attach_defaults ($popup, 1, 2, $row, $row+1);
+
+	$self->transcode_widgets->{tc_anti_alias_popup} = $popup;
+
 	return $frame;
 }
 
@@ -1382,6 +1384,13 @@ sub scan_rescale_volume {
 		);
 	}
 
+	if ( not $title->is_ripped ) {
+		$self->message_window (
+			message => "You first have to rip this title."
+		);
+		return 1;
+	}
+
 	my $nr;
 	my $last_job;
 	my $exec = Video::DVDRip::GUI::ExecuteJobs->new (
