@@ -1,4 +1,4 @@
-# $Id: TranscodeTabAudio.pm,v 1.3 2002/11/01 16:12:05 joern Exp $
+# $Id: TranscodeTabAudio.pm,v 1.5 2002/11/12 22:07:57 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -531,11 +531,17 @@ sub create_audio_filter {
 						->set_history($h);
 				}
 				if ( $key eq 'normalize' ) {
+					$title->set_tc_volume_rescale('');
 					$self->transcode_widgets
 					     ->{"audio_$type"}
 					     ->{tc_volume_rescale}
 					     ->set_text ('');
 				} else {
+					$title->set_tc_volume_rescale (
+						$title->audio_tracks
+						      ->[$title->audio_channel]
+						      ->volume_rescale
+					);
 					$self->transcode_widgets
 					     ->{"audio_$type"}
 					     ->{tc_volume_rescale}
@@ -581,6 +587,7 @@ sub create_audio_volume_rescale {
 	$hbox->show;
 	$entry = Video::DVDRip::CheckedEntry->new (undef,
 		is_number	=> 1,
+		may_fractional  => 1,
 		may_empty	=> 1,
 	);
 	$entry->show;
