@@ -1,4 +1,4 @@
-# $Id: Project.pm,v 1.31 2002/10/29 20:47:55 joern Exp $
+# $Id: Project.pm,v 1.33 2002/11/06 08:18:44 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -34,7 +34,6 @@ sub last_saved_data		{ shift->{last_saved_data}		}
 sub selected_title_nr		{ shift->{selected_title_nr}		}
 sub rip_mode			{ shift->{rip_mode} 	       || 'rip'	}
 sub dvd_image_dir		{ shift->{dvd_image_dir}		}
-sub vob_title_dir		{ shift->{vob_title_dir}		}
 sub convert_message		{ shift->{convert_message}		}
 sub last_selected_nb_page	{ shift->{last_selected_nb_page}	}
 
@@ -50,7 +49,6 @@ sub set_last_saved_data		{ shift->{last_saved_data}	= $_[1] }
 sub set_selected_title_nr	{ shift->{selected_title_nr}	= $_[1] }
 sub set_rip_mode		{ shift->{rip_mode}		= $_[1]	}
 sub set_dvd_image_dir		{ shift->{dvd_image_dir}	= $_[1]	}
-sub set_vob_title_dir		{ shift->{vob_title_dir}	= $_[1]	}
 sub set_convert_message		{ shift->{convert_message}	= $_[1]	}
 sub set_last_selected_nb_page	{ shift->{last_selected_nb_page}= $_[1]	}
 
@@ -129,7 +127,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Project.pm,v 1.31 2002/10/29 20:47:55 joern Exp $},"\n";
+	print $fh q{# $Id: Project.pm,v 1.33 2002/11/06 08:18:44 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -230,24 +228,6 @@ sub load {
 	1;
 }
 
-sub check_dvd_in_drive {
-	my $self = shift;
-	
-	my $dvd_mount_point;
-	my $rip_mode = $self->rip_mode;
-	
-	if ( $rip_mode eq 'dvd_image' ) {
-		$dvd_mount_point = $self->dvd_image_dir;
-	} else {
- 		$dvd_mount_point = $self->config('dvd_mount_point');
- 	}
-	
-	return 1 if -d "$dvd_mount_point/VIDEO_TS" or
-	            -d "$dvd_mount_point/video_ts";
-
-	croak "No DVD found at $dvd_mount_point.";
-}
-
 sub rip_data_source {
 	my $self = shift; $self->trace_in;
 	
@@ -261,8 +241,6 @@ sub rip_data_source {
 	} elsif ( $mode eq 'dvd_image' ) {
 		$source = $self->dvd_image_dir;
 
-	} elsif ( $mode eq 'vob_title' ) {
-		$source = $self->vob_title_dir;
 	}
 
 	return $source;
@@ -389,6 +367,9 @@ sub copy_ifo_files {
 
 	mkpath ( [ $self->ifo_dir  ], 0, 0755);
 
+	my $mounted = $self->dvd_is_mounted;
+	$self->mount_dvd if not $mounted;
+
 	my @files = glob (
 		$self->config('dvd_mount_point').
 		"/{video_ts,VIDEO_TS}/{vts,VTS}*{ifo,IFO}"
@@ -398,8 +379,30 @@ sub copy_ifo_files {
 		$self->log ("WARNING: no IFO files found - vobsub feature disabled.");
 	}
 
+	$self->log ("Copying IFO files to ".$self->ifo_dir);
+
 	copy ($_, $self->ifo_dir."/".lc(basename($_))) for @files;
 
+	$self->umount_dvd if not $mounted;
+
+	1;
+}
+
+sub check_dvd_in_drive {
+	my $self = shift;
+	
+	my $rip_mode = $self->rip_mode;
+
+	my $dvd_device = $self->rip_data_source;
+
+	my $command = "tcprobe -i $dvd_device >/dev/null 2>&1";
+
+	system ($command);
+	
+	if ( $? ) {
+		croak "No DVD found at $dvd_device.";
+	}
+	
 	1;
 }
 
@@ -422,10 +425,14 @@ sub mount_dvd {
 
 	my $dvd_mount_point = $self->config('dvd_mount_point');
 
-	my $mount = qx[ mount $dvd_mount_point 2>&1 ];
+	$self->log ("Mounting DVD at $dvd_mount_point");
 
-	$mount ||= "Ok";
-	$self->log ("Mount $dvd_mount_point: $mount");
+	my $mount = qx[ mount $dvd_mount_point 2>&1 && echo DVDRIP_SUCCESS ];
+
+	$mount =~ s/\s$//;
+
+	croak "msg:Failed to mount DVD at $dvd_mount_point ($mount)"
+		if $mount !~ /DVDRIP_SUCCESS/;
 
 	1;
 }
@@ -440,6 +447,7 @@ sub umount_dvd {
 	my $mount = qx[ umount $dvd_mount_point 2>&1 ];
 
 	$mount ||= "Ok";
+
 	$self->log ("Umount $dvd_mount_point: $mount");
 
 	1;
