@@ -1,4 +1,4 @@
-# $Id: Title.pm,v 1.103 2002/11/01 16:12:43 joern Exp $
+# $Id: Title.pm,v 1.108 2002/11/17 17:17:19 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -233,6 +233,14 @@ sub tc_audio_bitrate {
 	     ->tc_bitrate;
 }
 
+sub tc_mp2_bitrate {
+	my $self = shift;
+	return if $self->audio_channel == -1;
+	$self->tc_audio_tracks
+	     ->[$self->audio_channel]
+	     ->tc_mp2_bitrate;
+}
+
 sub tc_mp3_bitrate {
 	my $self = shift;
 	return if $self->audio_channel == -1;
@@ -305,6 +313,14 @@ sub set_tc_audio_bitrate {
 	     ->set_tc_bitrate ($_[0]);
 }
 
+sub set_tc_mp2_bitrate {
+	my $self = shift;
+	return if $self->audio_channel == -1;
+	$self->tc_audio_tracks
+	     ->[$self->audio_channel]
+	     ->set_tc_mp2_bitrate ($_[0]);
+}
+
 sub set_tc_mp3_bitrate {
 	my $self = shift;
 	return if $self->audio_channel == -1;
@@ -436,8 +452,6 @@ sub transcode_data_source {
 	} elsif ( $mode eq 'dvd_image' ) {
 		$source = $project->dvd_image_dir;
 
-	} elsif ( $mode eq 'vob_title' ) {
-		$source = $project->vob_title_dir;
 	}
 
 	return $source;
@@ -468,9 +482,6 @@ sub data_source_options {
 		$input_filter = "dvd";
 		$need_title = 1;
 
-	} elsif ( $mode eq 'vob_title' ) {
-		$input_filter = "vob";
-		$need_title = 0;
 	}
 
 	$input_filter .= ",null" if $audio_channel == -1;
@@ -842,11 +853,15 @@ sub auto_adjust_clip_zoom {
 	my $target_width = $width_presets{$frame_size};
 
 	my %result_by_ar_err;
-	foreach my $result ( @{$results} ) {
-		next if abs($target_width-$result->{clip2_width}) > 16;
-		$result_by_ar_err{abs($result->{ar_err})}
-			       ->{abs($target_width-$result->{clip2_width})}
-			       		= $result;
+	my $range = 16;
+	while ( keys (%result_by_ar_err) == 0 ) {
+		foreach my $result ( @{$results} ) {
+			next if abs($target_width-$result->{clip2_width}) > $range;
+			$result_by_ar_err{abs($result->{ar_err})}
+				       ->{abs($target_width-$result->{clip2_width})}
+				       		= $result;
+		}
+		$range += 16;
 	}
 
 	my ($min_err)        = sort { $a <=> $b} keys %result_by_ar_err;
@@ -964,6 +979,8 @@ sub get_zoom_parameters {
 	my  ($video_bitrate) =
 	@par{'video_bitrate'};
 
+#use Data::Dumper; print Dumper(\%par);
+
 	my ($clip1_top, $clip1_bottom, $clip1_left, $clip1_right);
 	my ($clip_top, $clip_bottom, $clip_left, $clip_right);
 
@@ -974,13 +991,17 @@ sub get_zoom_parameters {
 	$zoom_align  ||= $result_align if not $result_align_clip2;
 	$use_clip1 = 1 if not $auto_clip;
 	$video_bitrate ||= $self->tc_video_bitrate;
+
+#print "width=$width height=$height\n";
 	
 	# clip image
 	if ( $auto_clip ) {
-		$clip_top    = $self->bbox_min_y;
-		$clip_bottom = $height - $self->bbox_max_y;
-		$clip_left   = $self->bbox_min_x;
-		$clip_right  = $width - $self->bbox_max_x;
+		$clip_top    = $self->bbox_min_y || 0;
+		$clip_bottom = defined $self->bbox_max_y ?
+					$height - $self->bbox_max_y : 0;
+		$clip_left   = $self->bbox_min_x || 0;
+		$clip_right  = defined $self->bbox_max_x ?
+					$width - $self->bbox_max_x : 0;
 	} else {
 		$clip_top    = $self->tc_clip1_top;
 		$clip_bottom = $self->tc_clip1_bottom;
@@ -1018,6 +1039,8 @@ sub get_zoom_parameters {
 	my $clip_width  = $width  - $clip1_left - $clip1_right;
 	my $clip_height = $height - $clip1_top  - $clip1_bottom;
 
+#print "clip_width=$clip_width clip_height=$clip_height\n";
+
 	if ( not $target_height ) {
 		$target_width ||=
 			int($clip_width * $ar_width_factor -
@@ -1046,6 +1069,8 @@ sub get_zoom_parameters {
 	my $zoom_width  = $actual_width;
 	my $zoom_height = $actual_height;
 
+#print "actual_width=$actual_width actual_height=$actual_height\n";
+
 	if ( $zoom_width % $zoom_align ) {
 		$zoom_width = int($zoom_width / $zoom_align + 1) * $zoom_align
 			if $zoom_width % $zoom_align >= $zoom_align/2;
@@ -1060,10 +1085,14 @@ sub get_zoom_parameters {
 			if $zoom_height % $zoom_align < $zoom_align/2;
 	}
 
+#print "zoom_width=$zoom_width zoom_height=$zoom_height\n";
+
 	my $eff_ar = ($zoom_width/$zoom_height) * ($width/$height) /
 		     ($clip_width/$clip_height);
 	my $ar_err = abs(100 - $eff_ar / $ar * 100);
 
+#print "clip_left=$clip_left clip_right=$clip_right clip_top=$clip_top clip_bottom=$clip_bottom\n";
+
 	if ( not $use_clip1 ) {
 		$clip2_left   = int($clip_left   * $zoom_width/$clip_width   /2)*2;
 		$clip2_right  = int($clip_right  * $zoom_width/$clip_width   /2)*2;
@@ -1076,6 +1105,8 @@ sub get_zoom_parameters {
 	$clip2_width  = $zoom_width  - $clip2_left - $clip2_right;
 	$clip2_height = $zoom_height - $clip2_top  - $clip2_bottom;
 
+#print "clip2_width=$clip2_width clip2_height=$clip2_height\n";
+
 	if ( $result_align_clip2 ) {
 		my $rest;
 		if ( $rest = $clip2_width % $result_align ) {
@@ -1496,7 +1527,7 @@ sub get_optimal_video_bitrate {
 
 sub get_first_audio_track {
 	my $self = shift;
-	
+
 	return -1 if $self->audio_channel == -1;
 
 	foreach my $audio ( @{$self->tc_audio_tracks} ) {
@@ -2104,7 +2135,7 @@ sub get_frame_grab_options {
 			s/^\s+//;
 			s/\s+$//;
 			croak "msg:VOB navigation file '$vob_nav_file' is ".
-			      "corrupted. Please contact the author."
+			      "corrupted."
 				if !/^\d+\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+$/;
 			($block_offset, $frame_offset) =
 				(split (/\s+/, $_))[4,5];
@@ -2117,8 +2148,7 @@ sub get_frame_grab_options {
 	close $fh;
 	
 	croak "msg:Can't find frame $frame in VOB navigation file ".
-	      "'$vob_nav_file' (which has only $frames frames). ".
-	      "Please contact the author."
+	      "'$vob_nav_file' (which has only $frames frames). "
 		if not $found;
 	
 	return {
